##  Prerequisites
  * Administrator access in SAP LeanIX
  * Global administrator access to an SAP BTP cockpit that has the Cloud ALM API registered.
To find this information in Cloud ALM, go to Administration > Landscape Management > Services and Systems. Search for and select Cloud ALM and go to the Additional Details section of the Details tab.
  * All relevant customer numbers are registered in Cloud ALM (if more than one). Learn more in [2632518 ![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https://me.sap.com/notes/2632518).
After you set up the group, add an S-user from that group to SAP Cloud ALM. To do this, go to Administration> Landscape Management. Choose the settings (cog) icon to open the configuration screen. In the configuration screen, choose Add S-User.
